<template>
  <transition name="slide" mode="out-in" appear>
    <AppBar v-show="route.path.indexOf ('-fsv') == -1" class="no-print"></AppBar>
  </transition>

  <!-- <div :key="route.name"> -->
  <div class="py-6" id="main-content">
    <router-view v-slot="{ Component }">
        <error-boundary>
          <template v-slot:error>
            <error-template />
          </template>
          <transition name="fade" mode="out-in" appear>
            <keep-alive>
              <component :is="Component" />
            </keep-alive>
          </transition>
        </error-boundary>
    </router-view>
  </div>

  <transition name="fade" mode="out-in" appear>
    <div class="container-fluid mt-16 no-print" id="footer" v-show="route.path.indexOf ('-fsv') == -1">
      <div class="container pt-8 pb-8">
        <div class="row">
          <div class="col-sm-12 col-md-3 text-md-end text-sm-start pb-2">
            <div class="text-center ml-5">
              <img v-if="!!logoRiaas" :src="logoRiaas" width="120" height="26" class="opacity-90">
              <div class="fs-4 fw-bold text-blue-grey-lighten-1 mt-0 pt-0">KrackNet™</div>
            </div>
          </div>
          <div class="col-sm-12 col-md-9 pl-6">
            <ul class="list-inline mt-0 text-grey-lighten-3 pb-0 mb-2">
              <li class="list-inline-item d-none d-lg-inline"><router-link to="/" class="foot-link">Home</router-link> |</li>
              <li class="list-inline-item"><router-link to="/site-content/terms_of_use" class="foot-link">Terms of Use</router-link>| </li>
              <li class="list-inline-item"><router-link to="/site-content/privacy_policy" class="foot-link">Privacy Policy</router-link> |</li>
              <li class="list-inline-item"><router-link to="/site-content/contact_us" class="foot-link">Contact Us</router-link> |</li>
              <li class="list-inline-item"><router-link to="/site-content/about_kracknet" class="foot-link">About KrackNet</router-link></li>
            </ul>
            <div style="border-top: 1px dotted #888888;" class="text-blue-grey-lighten-2 pt-2 ml-2 fs-7">Copyright© 2023 <strong><span v-if="!!logoRiaas">Riaas KrackNet</span><span v-else>KrackNet.com</span> </strong> All Rights Reserved</div>
          </div>
        </div>
      </div>
      <transition name="fade" mode="out-in" appear>
        <div style="height: 60px;" v-if="!!state.$g.showTaskBar">
          <task-bar></task-bar>
        </div>
      </transition>
    </div>
  </transition>
</template>

<style scoped>
.foot-link {
  color: #bcdbf1;
  text-decoration: none;
  margin: 0 8px 0 8px;
  font-size: 14px;
}

#footer {
  background-color: #262a2e;
}

.fs-7 {
  font-size: small;
}
</style>


<script setup>

import AppBar from "./components/app-bar.vue"
import ErrorTemplate from "./components/error-template.vue"
import ErrorBoundary from "/atila-vue/components/error-boundary.vue"
import TaskBar from './tasks/components/task-bar.vue'

const route = useRoute ()
const { state } = useStore ()
const logoRiaas = window.location.host.endsWith ('riaas.ai') ? backend.static ('img/logo-riaas.png') : null

async function upgradeApp () {
  try {
    await idb.deleteDB ('default')
  } catch (e) {
    frontend.log ('deleting default DB failed')
  }
  if (!!state.$ls.get ('TASK')) {
    state.$ls.remove ('TASK')
  }
  if (!!state.$ls.get ('STAT')) {
    state.$ls.remove ('STAT')
  }
}

onBeforeMount (async () => {
  let pref = state.$ls.get ('PREFERENCE')
  if (!!pref) {
    state.pref = {...state.pref, ...pref}
  }
  await backend.refresh_access_token ("ATILA_VUE_AUTH_ACCESS_TOKEN")
  await frontend.get_site_config ()
  await frontend.initialize_task ()
  upgradeApp ()
})

onMounted (async () => {
  frontend.layout.keep_fill_height ("#main-content", 190, 800)
})

watch (() => route.fullPath, () => {
  frontend.layout.keep_fill_height ("#main-content", 190, 800)
})

</script>
